==> ocg_contact-0.0.1.tar.gz: lib/src/blocs/contact_sync.dart <==
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_contact/src/models/contact.dart';
import 'package:ocg_contact/src/repository/contact.dart';

///
/// Event
///
abstract class ContactSyncEvent {}

class ContactSyncAllEvent extends ContactSyncEvent {}

class ContactSyncListEvent extends ContactSyncEvent {
  final List<Contact> contacts;

  ContactSyncListEvent(this.contacts);
}

///
/// State
///
abstract class ContactSyncState {}

class ContactSyncIdleState extends ContactSyncState {}

class ContactSyncLoadingState extends ContactSyncState {}

class ContactSyncLoadedState extends ContactSyncState {}

class ContactSyncErrorState extends ContactSyncState {
  final String error;

  ContactSyncErrorState(this.error);
}

///
/// Bloc
///
class ContactSyncBloc extends Bloc<ContactSyncEvent, ContactSyncState> {
  final ContactRepository contactRepository;
  ContactSyncBloc(ContactSyncState initialState, this.contactRepository)
      : super(initialState);

  @override
  Stream<ContactSyncState> mapEventToState(ContactSyncEvent event) async* {
    if (event is ContactSyncAllEvent || event is ContactSyncListEvent) {
      List<Contact> contacts = [];
      yield ContactSyncLoadingState();
      if (event is ContactSyncAllEvent) {
        AppResponse<List<Contact>> contactResponse =
            await contactRepository.fetchPhoneContacts();
        if (contactResponse.isSuccess) {
          contacts = contactResponse.data;
        } else {
          yield ContactSyncErrorState(contactResponse.error);
          return;
        }
      } else if (event is ContactSyncListEvent) {
        contacts = event.contacts;
      }
      AppResponse<bool> syncResponse =
          await contactRepository.syncContacts(contacts);
      if (syncResponse.isSuccess) {
        yield ContactSyncLoadedState();
      } else {
        yield ContactSyncErrorState(syncResponse.error);
      }
    }
  }
}

==> ocg_contact-0.0.2.tar.gz: lib/src/blocs/contact_sync.dart <==
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_contact/src/models/contact.dart';
import 'package:ocg_contact/src/repository/contact.dart';

///
/// Event
///
abstract class ContactSyncEvent {}

class ContactSyncAllEvent extends ContactSyncEvent {}

class ContactSyncListEvent extends ContactSyncEvent {
  final List<Contact> contacts;

  ContactSyncListEvent(this.contacts);
}

///
/// State
///
abstract class ContactSyncState {}

class ContactSyncIdleState extends ContactSyncState {}

class ContactSyncLoadingState extends ContactSyncState {}

class ContactSyncLoadedState extends ContactSyncState {}

class ContactSyncErrorState extends ContactSyncState {
  final String error;

  ContactSyncErrorState(this.error);
}

///
/// Bloc
///
class ContactSyncBloc extends Bloc<ContactSyncEvent, ContactSyncState> {
  final ContactRepository contactRepository;
  ContactSyncBloc(this.contactRepository) : super(ContactSyncIdleState());

  @override
  Stream<ContactSyncState> mapEventToState(ContactSyncEvent event) async* {
    if (event is ContactSyncAllEvent || event is ContactSyncListEvent) {
      List<Contact> contacts = [];
      yield ContactSyncLoadingState();
      if (event is ContactSyncAllEvent) {
        AppResponse<List<Contact>> contactResponse =
            await contactRepository.fetchPhoneContacts();
        if (contactResponse.isSuccess) {
          contacts = contactResponse.data;
        } else {
          yield ContactSyncErrorState(contactResponse.error);
          return;
        }
      } else if (event is ContactSyncListEvent) {
        contacts = event.contacts;
      }
      AppResponse<bool> syncResponse =
          await contactRepository.syncContacts(contacts);
      if (syncResponse.isSuccess) {
        yield ContactSyncLoadedState();
      } else {
        yield ContactSyncErrorState(syncResponse.error);
      }
    }
  }
}
